@@ -30,10 +30,12 @@ class HorizontalVolumeBarWidget : public VolumeMeterWidget
 public:
     HorizontalVolumeBarWidget(QWidget *parent);
 
+protected:
     void draw(QPainter *painter);
 
-protected:
-    void paintEvent(QPaintEvent *event);
+private:
+    void drawBackground();
+
 };
 
 #endif // HORIZONTALVOLUMEBARWIDGET_H
