@@ -23,15 +23,49 @@
 #include <QRect>
 
 VolumeMeterWidget::VolumeMeterWidget(QWidget *parent) :
-    QWidget(parent)
+    QGLWidget(QGLFormat(QGL::SampleBuffers), parent)
 {
     currentValue = 0;
+    background = NULL;
     setSizePolicy(QSizePolicy::Expanding, QSizePolicy::Expanding);
 }
 
+void VolumeMeterWidget::initPainter(QPainter *painter){
+    painter->setRenderHint(QPainter::Antialiasing, true);
+
+    float h = height();
+    float w = width();
+
+    if(w > (RATIO * h)){
+        w = RATIO * h;
+    }else{
+        h = w / RATIO;
+    }
+
+    painter->setViewport(0, 0, w, h);
+    painter->setWindow(0, 0, w, h);
+}
+
+void VolumeMeterWidget::mouseReleaseEvent(QMouseEvent */*event*/){
+    emit clicked();
+}
+
+void VolumeMeterWidget::paintEvent(QPaintEvent */*event*/){
+    QPainter painter(this);
+
+    initPainter(& painter);
+
+    draw(& painter);
+}
+
+void VolumeMeterWidget::resizeEvent(QResizeEvent */*event*/){
+    background = NULL;
+}
+
 void VolumeMeterWidget::setDbUnit(bool b){
     dbUnit = b;
     currentValue = 0;
+    background = NULL;
     emit update();
 }
 
@@ -39,7 +73,3 @@ void VolumeMeterWidget::updateValue(int value){
     currentValue = value;
     emit update();
 }
-
-void VolumeMeterWidget::mouseReleaseEvent(QMouseEvent */*event*/){
-    emit clicked();
-}
