@@ -20,12 +20,15 @@
 #ifndef VOLUMEMETERWIDGET_H
 #define VOLUMEMETERWIDGET_H
 
-#include <QWidget>
+#include <QImage>
+#include <QPainter>
+#include <QtOpenGL/QGLWidget>
 
 #define MAX_DB 110
 #define MAX_LINEAR 200
+#define RATIO 3.
 
-class VolumeMeterWidget : public QWidget
+class VolumeMeterWidget : public QGLWidget
 {
     Q_OBJECT
 public:
@@ -38,10 +41,15 @@ signals:
     void clicked();
 
 protected:
+    QImage *background;
     int currentValue;
     bool dbUnit;
 
+    virtual void draw(QPainter *painter) = 0;
+    virtual void initPainter(QPainter *painter);
     void mouseReleaseEvent(QMouseEvent *);
+    virtual void paintEvent(QPaintEvent *event);
+    virtual void resizeEvent(QResizeEvent *event);
 };
 
 #endif // VOLUMEMETERWIDGET_H
